@@ -38,12 +38,12 @@ def run_dbt(profiles_dir: str, project_dir: str) -> None:
     try:
         subprocess.run(
             ["dbt", "test", "--profiles-dir", profiles_dir, "--project-dir", project_dir],
-            check=True, capture_output=True
+            check=True, capture_output=True, encoding="utf-8"
         )
         subprocess.run(
             ["dbt", "run", "--profiles-dir", profiles_dir, "--project-dir", project_dir],
-            check=True, capture_output=True
+            check=True, capture_output=True, encoding="utf-8"
         )
     except subprocess.CalledProcessError as exc:
-        errtext = exc.stdout.decode("utf-8") + "\n" + exc.stderr.decode("utf-8")
+        errtext = exc.stdout + "\n" + exc.stderr
         raise Exception(errtext) from exc
